Classic API Models

Note

The intended use of SDK models is to provide an easier developer experience when working with requests and responses. All fields are optional, and extra fields are allowed for when Jamf releases a new version that adds additional fields that are not yet reflected in the SDK. These extra fields when present may or may not reflect their actual types. Do not rely solely on the SDK models for data validation.

Shared Models

ClassicApiModel(**kwargs)

The base model used for Classic API models.

ClassicDeviceLocation(*[, username, ...])

Device user assignment information.

ClassicDevicePurchasing(*[, is_purchased, ...])

Device purchase information (normally populated by GSX).

ClassicSite(*[, id, name])

Site assignment information.

Categories

ClassicCategory(*[, id, name, priority])

Represents a category record returned by the get_category_by_id() operation.

ClassicCategoriesItem(*[, id, name])

Represents a category record returned by the list_all_categories() operation.

Advanced Computer Searches

ClassicAdvancedComputerSearch(*[, id, name, ...])

Represents an advanced computer search record returned by the list_all_advanced_computer_searches() operation.

ClassicAdvancedComputerSearchesItem(*[, id, ...])

Represents an advanced computer search record returned by the list_all_advanced_computer_searches() operation.

ClassicAdvancedComputerSearchResult(*[, id, ...])

ClassicAdvancedComputerSearch nested model: advanced_computer_search.computers.

ClassicAdvancedComputerSearchDisplayField(*)

ClassicAdvancedComputerSearch nested model: advanced_computer_search.display_fields.

Computers

ClassicComputer(*, general, location, ...)

Represents a full computer inventory record.

ClassicComputersItem(*, id, name[, managed, ...])

Represents a computer record returned by the list_computers() operation.

ClassicComputerGeneral(*[, id, name, ...])

Computer nested model: computer.general

ClassicComputerGeneralRemoteManagement(*[, ...])

Computer nested model: computer.general.remote_management

ClassicComputerGeneralMdmCapableUsers(*[, ...])

Computer nested model: computer.general.mdm_capable_users

ClassicComputerGeneralManagementStatus(*[, ...])

Computer nested model: computer.general.management_status

ClassicComputerHardware(*[, make, model, ...])

Computer nested model: computer.hardware

ClassicComputerHardwareStorageDevice(*[, ...])

Computer nested model: computer.hardware.storage

ClassicComputerHardwareStorageDevicePartition(*)

Computer nested model: computer.hardware.storage.partitions

ClassicComputerHardwareMappedPrinter(*[, ...])

Computer nested model: computer.hardware.mapped_printers

ClassicComputerCertificate(*[, common_name, ...])

Computer nested model: computer.certificates

ClassicComputerSecurity(*[, ...])

Computer nested model: computer.security

ClassicComputerSoftware(*[, ...])

Computer nested model: computer.software

ClassicComputerSoftwareItem(*[, name, path, ...])

Computer nested model: computer.software.applications, computer.software.fonts, computer.software.plugins

ClassicComputerSoftwareAvailableUpdate(*[, ...])

Computer nested model: computer.software.available_updates

ClassicComputerExtensionAttribute(*[, id, ...])

Computer nested model: computer.extension_attributes

ClassicComputerGroupsAccounts(*[, ...])

Computer nested model: computer.groups_accounts

ClassicComputerGroupsAccountsLocalAccount(*)

Computer nested model: computer.groups_accounts.local_accounts

ClassicComputerGroupsAccountsUserInventories(*)

Computer nested model: computer.groups_accounts.user_inventories

ClassicComputerGroupsAccountsUserInventoriesUser(*)

Computer nested model: computer.groups_accounts.user_inventories.user

ClassicComputerConfigurationProfile(*[, id, ...])

Computer nested model: computer.configuration_profiles

Computer Groups

ClassicComputerGroup

Represents a computer group record returned by the list_computer_groups() and get_computer_group_by_id() operations.

ClassicComputerGroupMember

ComputerGroup nested model: computer_group.computers, computer_group.computer_additions, computer_group.computer_deletions

ClassicComputerGroupMembershipUpdate

Represents a computer group membership update.

Network Segments

ClassicNetworkSegment(*[, id, name, ...])

Represents a network_segment record returned by the get_network_segment_by_id() operation.

ClassicNetworkSegmentItem(*[, id, name, ...])

Represents a network_segment record returned by the list_network_segments() operation.

Packages

ClassicPackage(*[, id, name, category, ...])

Represents a package returned by the get_package_by_id() operation.

ClassicPackageItem(*[, id, name])

Represents a package record returned by the list_packages() operation.

Group and Search Criteria

ClassicCriterion(*, name, priority, and_or, ...)

Classic API criterion.

ClassicCriterionSearchType(*values)

Supported search types for Classic API criteria.