Pro API Models

Note

The intended use of SDK models is to provide an easier developer experience when working with requests and responses. All fields are optional, and extra fields are allowed for when Jamf releases a new version that adds additional fields that are not yet reflected in the SDK. These extra fields when present may or may not reflect their actual types. Do not rely solely on the SDK models for data validation.

Computers

Computer(*, id, udid, general, ...)

Represents a full computer inventory record.

ComputerGeneral(*, name, lastIpAddress, ...)

ComputerDiskEncryption(*[, ...])

ComputerPurchase(*[, leased, purchased, ...])

ComputerApplication(*[, name, path, ...])

ComputerStorage(*[, ...])

ComputerUserAndLocation(*[, username, ...])

ComputerConfigurationProfile(*[, id, ...])

ComputerPrinter(*[, name, type, uri, location])

ComputerService(*[, name])

ComputerHardware(*[, make, model, ...])

ComputerLocalUserAccount(*[, uid, username, ...])

ComputerCertificate(*[, commonName, ...])

ComputerAttachment(*[, id, name, fileType, ...])

ComputerPlugin(*[, name, version, path])

ComputerPackageReceipts(*[, ...])

ComputerFont(*[, name, version, path])

ComputerSecurity(*[, sipStatus, ...])

ComputerOperatingSystem(*[, name, version, ...])

ComputerLicensedSoftware(*[, id, name])

ComputeriBeacon(*[, name])

ComputerSoftwareUpdate(*[, name, version, ...])

ComputerExtensionAttribute(*[, ...])

ComputerContentCaching(*[, ...])

ComputerGroupMembership(*[, groupId, ...])

Packages

Package(*, id, packageName, fileName, ...)

Represents a full package record.

JCDS2

NewFile(*, accessKeyID, secretAccessKey, ...)

Create a new model by parsing and validating input data from keyword arguments.

File(*, region, fileName, length, md5, sha3, ...)

Create a new model by parsing and validating input data from keyword arguments.

DownloadUrl(*, uri, **extra_data)

Create a new model by parsing and validating input data from keyword arguments.

MDM Commands

SendMdmCommand(*, clientData, commandData)

Create a new model by parsing and validating input data from keyword arguments.

SendMdmCommandClientData(*, managementId)

Create a new model by parsing and validating input data from keyword arguments.

EnableLostModeCommand(*[, commandType])

MDM command to enable Lost Mode.

EraseDeviceCommand(*[, commandType, ...])

MDM command to remotely wipe a device.

EraseDeviceCommandObliterationBehavior(*values)

Define the fallback behavior for erasing a device.

EraseDeviceCommandReturnToService(*, ...)

Configuration settings for Return to Service.

LogOutUserCommand(*[, commandType])

MDM command to log a user out of the device.

RestartDeviceCommand(*[, commandType])

MDM command to restart a device.

ShutDownDeviceCommand(*[, commandType])

MDM command to shut down a device.

SendMdmCommandResponse(*, id, href, **extra_data)

Create a new model by parsing and validating input data from keyword arguments.

RenewMdmProfileResponse(*, ...)

This response model flattens the normal API JSON response from a nested udidsNotProcessed.uuids array to just udidsNotProcessed.

RedeployManagementFrameworkResponse(*[, ...])

The response returned when redeploying the Jamf management framework to a computer.

MdmCommandStatus(*, uuid, client, ...[, ...])

Create a new model by parsing and validating input data from keyword arguments.

MdmCommandStatusClient(*, managementId, ...)

Create a new model by parsing and validating input data from keyword arguments.

MdmCommandStatusClientTypes(*values)

MdmCommandStatusStates(*values)

MdmCommandStatusTypes(*values)

Mobile Devices

MobileDevice(*[, mobileDeviceId, ...])

Represents a full mobile device inventory record.

MobileDeviceHardware(*[, capacityMb, ...])

MobileDeviceUserAndLocation(*[, username, ...])

MobileDevicePurchasing(*[, purchased, ...])

MobileDeviceApplication(*[, identifier, ...])

MobileDeviceCertificate(*[, commonName, ...])

MobileDeviceProfile(*[, displayName, ...])

MobileDeviceUserProfile(*[, displayName, ...])

Extends MobileDeviceProfile.

MobileDeviceExtensionAttribute(*[, id, ...])

MobileDeviceGeneral(*[, udid, displayName, ...])

MobileDeviceOwnershipType(*values)

MobileDeviceEnrollmentMethodPrestage(*[, ...])

MobileDeviceSecurity(*[, dataProtected, ...])

iOS devices only.

MobileDeviceEbook(*[, author, title, ...])

iOS devices only.

MobileDeviceNetwork(*[, cellularTechnology, ...])

iOS devices only.

MobileDeviceServiceSubscription(*[, ...])

iOS devices only.

ProvisioningProfile(*[, displayName, uuid, ...])

iOS devices only.

SharedUser(*[, managedAppleId, loggedIn, ...])

iOS devices only.

Pagination

Page(*, page, page_count, total_count, results)

A page result from a Pro API paginator.

FilterEntry(name, op, value)